# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: recomendations.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='recomendations.proto',
  package='recomendator',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14recomendations.proto\x12\x0crecomendator\"q\n\x04\x42ook\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04isbn\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\x05\x12\r\n\x05genre\x18\x05 \x03(\x05\x12\x0f\n\x07summary\x18\x06 \x01(\t\x12\x10\n\x08language\x18\x07 \x01(\x05\"#\n\x15RecomendationsRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x32_\n\x18RecomendationsController\x12\x43\n\x04List\x12#.recomendator.RecomendationsRequest\x1a\x12.recomendator.Book\"\x00\x30\x01\x62\x06proto3'
)




_BOOK = _descriptor.Descriptor(
  name='Book',
  full_name='recomendator.Book',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='recomendator.Book.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='recomendator.Book.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isbn', full_name='recomendator.Book.isbn', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author', full_name='recomendator.Book.author', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='genre', full_name='recomendator.Book.genre', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary', full_name='recomendator.Book.summary', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='recomendator.Book.language', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=151,
)


_RECOMENDATIONSREQUEST = _descriptor.Descriptor(
  name='RecomendationsRequest',
  full_name='recomendator.RecomendationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='recomendator.RecomendationsRequest.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=188,
)

DESCRIPTOR.message_types_by_name['Book'] = _BOOK
DESCRIPTOR.message_types_by_name['RecomendationsRequest'] = _RECOMENDATIONSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Book = _reflection.GeneratedProtocolMessageType('Book', (_message.Message,), {
  'DESCRIPTOR' : _BOOK,
  '__module__' : 'recomendations_pb2'
  # @@protoc_insertion_point(class_scope:recomendator.Book)
  })
_sym_db.RegisterMessage(Book)

RecomendationsRequest = _reflection.GeneratedProtocolMessageType('RecomendationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _RECOMENDATIONSREQUEST,
  '__module__' : 'recomendations_pb2'
  # @@protoc_insertion_point(class_scope:recomendator.RecomendationsRequest)
  })
_sym_db.RegisterMessage(RecomendationsRequest)



_RECOMENDATIONSCONTROLLER = _descriptor.ServiceDescriptor(
  name='RecomendationsController',
  full_name='recomendator.RecomendationsController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=190,
  serialized_end=285,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='recomendator.RecomendationsController.List',
    index=0,
    containing_service=None,
    input_type=_RECOMENDATIONSREQUEST,
    output_type=_BOOK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RECOMENDATIONSCONTROLLER)

DESCRIPTOR.services_by_name['RecomendationsController'] = _RECOMENDATIONSCONTROLLER

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from common.pb2 import book_pb2 as catalog_dot_book__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class BookControllerStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.List = channel.unary_stream(
        '/catalog.BookController/List',
        request_serializer=catalog_dot_book__pb2.BookListRequest.SerializeToString,
        response_deserializer=catalog_dot_book__pb2.Book.FromString,
        )
    self.Create = channel.unary_unary(
        '/catalog.BookController/Create',
        request_serializer=catalog_dot_book__pb2.Book.SerializeToString,
        response_deserializer=catalog_dot_book__pb2.Book.FromString,
        )
    self.Retrieve = channel.unary_unary(
        '/catalog.BookController/Retrieve',
        request_serializer=catalog_dot_book__pb2.BookRetrieveRequest.SerializeToString,
        response_deserializer=catalog_dot_book__pb2.Book.FromString,
        )
    self.Update = channel.unary_unary(
        '/catalog.BookController/Update',
        request_serializer=catalog_dot_book__pb2.Book.SerializeToString,
        response_deserializer=catalog_dot_book__pb2.Book.FromString,
        )
    self.Destroy = channel.unary_unary(
        '/catalog.BookController/Destroy',
        request_serializer=catalog_dot_book__pb2.Book.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class BookControllerServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def List(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Retrieve(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Destroy(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    print('IN DESTROY CONTROLLER')
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemente----d!')
    raise NotImplementedError('Method not imple---mented!')


def add_BookControllerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'List': grpc.unary_stream_rpc_method_handler(
          servicer.List,
          request_deserializer=catalog_dot_book__pb2.BookListRequest.FromString,
          response_serializer=catalog_dot_book__pb2.Book.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=catalog_dot_book__pb2.Book.FromString,
          response_serializer=catalog_dot_book__pb2.Book.SerializeToString,
      ),
      'Retrieve': grpc.unary_unary_rpc_method_handler(
          servicer.Retrieve,
          request_deserializer=catalog_dot_book__pb2.BookRetrieveRequest.FromString,
          response_serializer=catalog_dot_book__pb2.Book.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=catalog_dot_book__pb2.Book.FromString,
          response_serializer=catalog_dot_book__pb2.Book.SerializeToString,
      ),
      'Destroy': grpc.unary_unary_rpc_method_handler(
          servicer.Destroy,
          request_deserializer=catalog_dot_book__pb2.Book.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'catalog.BookController', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: catalog/book.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='catalog/book.proto',
  package='catalog',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x12\x63\x61talog/book.proto\x12\x07\x63\x61talog\x1a\x1bgoogle/protobuf/empty.proto\"q\n\x04\x42ook\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04isbn\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\x05\x12\r\n\x05genre\x18\x05 \x03(\x05\x12\x0f\n\x07summary\x18\x06 \x01(\t\x12\x10\n\x08language\x18\x07 \x01(\x05\"\x11\n\x0f\x42ookListRequest\"!\n\x13\x42ookRetrieveRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x32\x88\x02\n\x0e\x42ookController\x12\x33\n\x04List\x12\x18.catalog.BookListRequest\x1a\r.catalog.Book\"\x00\x30\x01\x12(\n\x06\x43reate\x12\r.catalog.Book\x1a\r.catalog.Book\"\x00\x12\x39\n\x08Retrieve\x12\x1c.catalog.BookRetrieveRequest\x1a\r.catalog.Book\"\x00\x12(\n\x06Update\x12\r.catalog.Book\x1a\r.catalog.Book\"\x00\x12\x32\n\x07\x44\x65stroy\x12\r.catalog.Book\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_BOOK = _descriptor.Descriptor(
  name='Book',
  full_name='catalog.Book',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='catalog.Book.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='catalog.Book.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isbn', full_name='catalog.Book.isbn', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='author', full_name='catalog.Book.author', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='genre', full_name='catalog.Book.genre', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='catalog.Book.summary', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='catalog.Book.language', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=173,
)


_BOOKLISTREQUEST = _descriptor.Descriptor(
  name='BookListRequest',
  full_name='catalog.BookListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=192,
)


_BOOKRETRIEVEREQUEST = _descriptor.Descriptor(
  name='BookRetrieveRequest',
  full_name='catalog.BookRetrieveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='catalog.BookRetrieveRequest.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=227,
)

DESCRIPTOR.message_types_by_name['Book'] = _BOOK
DESCRIPTOR.message_types_by_name['BookListRequest'] = _BOOKLISTREQUEST
DESCRIPTOR.message_types_by_name['BookRetrieveRequest'] = _BOOKRETRIEVEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Book = _reflection.GeneratedProtocolMessageType('Book', (_message.Message,), {
  'DESCRIPTOR' : _BOOK,
  '__module__' : 'catalog.book_pb2'
  # @@protoc_insertion_point(class_scope:catalog.Book)
  })
_sym_db.RegisterMessage(Book)

BookListRequest = _reflection.GeneratedProtocolMessageType('BookListRequest', (_message.Message,), {
  'DESCRIPTOR' : _BOOKLISTREQUEST,
  '__module__' : 'catalog.book_pb2'
  # @@protoc_insertion_point(class_scope:catalog.BookListRequest)
  })
_sym_db.RegisterMessage(BookListRequest)

BookRetrieveRequest = _reflection.GeneratedProtocolMessageType('BookRetrieveRequest', (_message.Message,), {
  'DESCRIPTOR' : _BOOKRETRIEVEREQUEST,
  '__module__' : 'catalog.book_pb2'
  # @@protoc_insertion_point(class_scope:catalog.BookRetrieveRequest)
  })
_sym_db.RegisterMessage(BookRetrieveRequest)



_BOOKCONTROLLER = _descriptor.ServiceDescriptor(
  name='BookController',
  full_name='catalog.BookController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=230,
  serialized_end=494,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='catalog.BookController.List',
    index=0,
    containing_service=None,
    input_type=_BOOKLISTREQUEST,
    output_type=_BOOK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='catalog.BookController.Create',
    index=1,
    containing_service=None,
    input_type=_BOOK,
    output_type=_BOOK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Retrieve',
    full_name='catalog.BookController.Retrieve',
    index=2,
    containing_service=None,
    input_type=_BOOKRETRIEVEREQUEST,
    output_type=_BOOK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='catalog.BookController.Update',
    index=3,
    containing_service=None,
    input_type=_BOOK,
    output_type=_BOOK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Destroy',
    full_name='catalog.BookController.Destroy',
    index=4,
    containing_service=None,
    input_type=_BOOK,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_BOOKCONTROLLER)

DESCRIPTOR.services_by_name['BookController'] = _BOOKCONTROLLER

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from common.pb2 import book_instance_pb2 as catalog_dot_book__instance__pb2


class BookInstanceControllerStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.List = channel.unary_stream(
        '/catalog.BookInstanceController/List',
        request_serializer=catalog_dot_book__instance__pb2.BookInstanceListRequest.SerializeToString,
        response_deserializer=catalog_dot_book__instance__pb2.BookInstance.FromString,
        )
    self.Create = channel.unary_unary(
        '/catalog.BookInstanceController/Create',
        request_serializer=catalog_dot_book__instance__pb2.BookInstance.SerializeToString,
        response_deserializer=catalog_dot_book__instance__pb2.BookInstance.FromString,
        )
    self.MyList = channel.unary_stream(
        '/catalog.BookInstanceController/MyList',
        request_serializer=catalog_dot_book__instance__pb2.MyBookInstanceListRequest.SerializeToString,
        response_deserializer=catalog_dot_book__instance__pb2.BookInstance.FromString,
        )
    self.Renew = channel.unary_unary(
        '/catalog.BookInstanceController/Renew',
        request_serializer=catalog_dot_book__instance__pb2.BookInstanceRenewal.SerializeToString,
        response_deserializer=catalog_dot_book__instance__pb2.BookInstance.FromString,
        )


class BookInstanceControllerServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def List(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MyList(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Renew(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_BookInstanceControllerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'List': grpc.unary_stream_rpc_method_handler(
          servicer.List,
          request_deserializer=catalog_dot_book__instance__pb2.BookInstanceListRequest.FromString,
          response_serializer=catalog_dot_book__instance__pb2.BookInstance.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=catalog_dot_book__instance__pb2.BookInstance.FromString,
          response_serializer=catalog_dot_book__instance__pb2.BookInstance.SerializeToString,
      ),
      'MyList': grpc.unary_stream_rpc_method_handler(
          servicer.MyList,
          request_deserializer=catalog_dot_book__instance__pb2.MyBookInstanceListRequest.FromString,
          response_serializer=catalog_dot_book__instance__pb2.BookInstance.SerializeToString,
      ),
      'Renew': grpc.unary_unary_rpc_method_handler(
          servicer.Renew,
          request_deserializer=catalog_dot_book__instance__pb2.BookInstanceRenewal.FromString,
          response_serializer=catalog_dot_book__instance__pb2.BookInstance.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'catalog.BookInstanceController', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: catalog/book_instance.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='catalog/book_instance.proto',
  package='catalog',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x1b\x63\x61talog/book_instance.proto\x12\x07\x63\x61talog\"m\n\x0c\x42ookInstance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x62ook\x18\x02 \x01(\x05\x12\x0f\n\x07imprint\x18\x03 \x01(\t\x12\x10\n\x08\x64ue_back\x18\x04 \x01(\t\x12\x10\n\x08\x62orrower\x18\x05 \x01(\x05\x12\x0e\n\x06status\x18\x06 \x01(\t\"3\n\x13\x42ookInstanceRenewal\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x64ue_back\x18\x02 \x01(\t\"-\n\x19MyBookInstanceListRequest\x12\x10\n\x08\x62orrower\x18\x01 \x01(\x05\"\x19\n\x17\x42ookInstanceListRequest2\xa0\x02\n\x16\x42ookInstanceController\x12\x43\n\x04List\x12 .catalog.BookInstanceListRequest\x1a\x15.catalog.BookInstance\"\x00\x30\x01\x12\x38\n\x06\x43reate\x12\x15.catalog.BookInstance\x1a\x15.catalog.BookInstance\"\x00\x12G\n\x06MyList\x12\".catalog.MyBookInstanceListRequest\x1a\x15.catalog.BookInstance\"\x00\x30\x01\x12>\n\x05Renew\x12\x1c.catalog.BookInstanceRenewal\x1a\x15.catalog.BookInstance\"\x00\x62\x06proto3'
)




_BOOKINSTANCE = _descriptor.Descriptor(
  name='BookInstance',
  full_name='catalog.BookInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='catalog.BookInstance.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='book', full_name='catalog.BookInstance.book', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='imprint', full_name='catalog.BookInstance.imprint', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='due_back', full_name='catalog.BookInstance.due_back', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='borrower', full_name='catalog.BookInstance.borrower', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='catalog.BookInstance.status', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=149,
)


_BOOKINSTANCERENEWAL = _descriptor.Descriptor(
  name='BookInstanceRenewal',
  full_name='catalog.BookInstanceRenewal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='catalog.BookInstanceRenewal.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='due_back', full_name='catalog.BookInstanceRenewal.due_back', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=202,
)


_MYBOOKINSTANCELISTREQUEST = _descriptor.Descriptor(
  name='MyBookInstanceListRequest',
  full_name='catalog.MyBookInstanceListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='borrower', full_name='catalog.MyBookInstanceListRequest.borrower', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=249,
)


_BOOKINSTANCELISTREQUEST = _descriptor.Descriptor(
  name='BookInstanceListRequest',
  full_name='catalog.BookInstanceListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=276,
)

DESCRIPTOR.message_types_by_name['BookInstance'] = _BOOKINSTANCE
DESCRIPTOR.message_types_by_name['BookInstanceRenewal'] = _BOOKINSTANCERENEWAL
DESCRIPTOR.message_types_by_name['MyBookInstanceListRequest'] = _MYBOOKINSTANCELISTREQUEST
DESCRIPTOR.message_types_by_name['BookInstanceListRequest'] = _BOOKINSTANCELISTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BookInstance = _reflection.GeneratedProtocolMessageType('BookInstance', (_message.Message,), {
  'DESCRIPTOR' : _BOOKINSTANCE,
  '__module__' : 'catalog.book_instance_pb2'
  # @@protoc_insertion_point(class_scope:catalog.BookInstance)
  })
_sym_db.RegisterMessage(BookInstance)

BookInstanceRenewal = _reflection.GeneratedProtocolMessageType('BookInstanceRenewal', (_message.Message,), {
  'DESCRIPTOR' : _BOOKINSTANCERENEWAL,
  '__module__' : 'catalog.book_instance_pb2'
  # @@protoc_insertion_point(class_scope:catalog.BookInstanceRenewal)
  })
_sym_db.RegisterMessage(BookInstanceRenewal)

MyBookInstanceListRequest = _reflection.GeneratedProtocolMessageType('MyBookInstanceListRequest', (_message.Message,), {
  'DESCRIPTOR' : _MYBOOKINSTANCELISTREQUEST,
  '__module__' : 'catalog.book_instance_pb2'
  # @@protoc_insertion_point(class_scope:catalog.MyBookInstanceListRequest)
  })
_sym_db.RegisterMessage(MyBookInstanceListRequest)

BookInstanceListRequest = _reflection.GeneratedProtocolMessageType('BookInstanceListRequest', (_message.Message,), {
  'DESCRIPTOR' : _BOOKINSTANCELISTREQUEST,
  '__module__' : 'catalog.book_instance_pb2'
  # @@protoc_insertion_point(class_scope:catalog.BookInstanceListRequest)
  })
_sym_db.RegisterMessage(BookInstanceListRequest)



_BOOKINSTANCECONTROLLER = _descriptor.ServiceDescriptor(
  name='BookInstanceController',
  full_name='catalog.BookInstanceController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=279,
  serialized_end=567,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='catalog.BookInstanceController.List',
    index=0,
    containing_service=None,
    input_type=_BOOKINSTANCELISTREQUEST,
    output_type=_BOOKINSTANCE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='catalog.BookInstanceController.Create',
    index=1,
    containing_service=None,
    input_type=_BOOKINSTANCE,
    output_type=_BOOKINSTANCE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MyList',
    full_name='catalog.BookInstanceController.MyList',
    index=2,
    containing_service=None,
    input_type=_MYBOOKINSTANCELISTREQUEST,
    output_type=_BOOKINSTANCE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Renew',
    full_name='catalog.BookInstanceController.Renew',
    index=3,
    containing_service=None,
    input_type=_BOOKINSTANCERENEWAL,
    output_type=_BOOKINSTANCE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_BOOKINSTANCECONTROLLER)

DESCRIPTOR.services_by_name['BookInstanceController'] = _BOOKINSTANCECONTROLLER

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: catalog/language.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='catalog/language.proto',
  package='catalog',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x16\x63\x61talog/language.proto\x12\x07\x63\x61talog\"$\n\x08Language\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13LanguageListRequest2Q\n\x12LanguageController\x12;\n\x04List\x12\x1c.catalog.LanguageListRequest\x1a\x11.catalog.Language\"\x00\x30\x01\x62\x06proto3'
)




_LANGUAGE = _descriptor.Descriptor(
  name='Language',
  full_name='catalog.Language',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='catalog.Language.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='catalog.Language.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=71,
)


_LANGUAGELISTREQUEST = _descriptor.Descriptor(
  name='LanguageListRequest',
  full_name='catalog.LanguageListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=94,
)

DESCRIPTOR.message_types_by_name['Language'] = _LANGUAGE
DESCRIPTOR.message_types_by_name['LanguageListRequest'] = _LANGUAGELISTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Language = _reflection.GeneratedProtocolMessageType('Language', (_message.Message,), {
  'DESCRIPTOR' : _LANGUAGE,
  '__module__' : 'catalog.language_pb2'
  # @@protoc_insertion_point(class_scope:catalog.Language)
  })
_sym_db.RegisterMessage(Language)

LanguageListRequest = _reflection.GeneratedProtocolMessageType('LanguageListRequest', (_message.Message,), {
  'DESCRIPTOR' : _LANGUAGELISTREQUEST,
  '__module__' : 'catalog.language_pb2'
  # @@protoc_insertion_point(class_scope:catalog.LanguageListRequest)
  })
_sym_db.RegisterMessage(LanguageListRequest)



_LANGUAGECONTROLLER = _descriptor.ServiceDescriptor(
  name='LanguageController',
  full_name='catalog.LanguageController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=96,
  serialized_end=177,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='catalog.LanguageController.List',
    index=0,
    containing_service=None,
    input_type=_LANGUAGELISTREQUEST,
    output_type=_LANGUAGE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_LANGUAGECONTROLLER)

DESCRIPTOR.services_by_name['LanguageController'] = _LANGUAGECONTROLLER

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: catalog/author.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='catalog/author.proto',
  package='catalog',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x14\x63\x61talog/author.proto\x12\x07\x63\x61talog\x1a\x1bgoogle/protobuf/empty.proto\"i\n\x06\x41uthor\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x11\n\tlast_name\x18\x03 \x01(\t\x12\x15\n\rdate_of_birth\x18\x04 \x01(\t\x12\x15\n\rdate_of_death\x18\x05 \x01(\t\"\x13\n\x11\x41uthorListRequest\"#\n\x15\x41uthorRetrieveRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x32\x9c\x02\n\x10\x41uthorController\x12\x37\n\x04List\x12\x1a.catalog.AuthorListRequest\x1a\x0f.catalog.Author\"\x00\x30\x01\x12,\n\x06\x43reate\x12\x0f.catalog.Author\x1a\x0f.catalog.Author\"\x00\x12=\n\x08Retrieve\x12\x1e.catalog.AuthorRetrieveRequest\x1a\x0f.catalog.Author\"\x00\x12,\n\x06Update\x12\x0f.catalog.Author\x1a\x0f.catalog.Author\"\x00\x12\x34\n\x07\x44\x65stroy\x12\x0f.catalog.Author\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_AUTHOR = _descriptor.Descriptor(
  name='Author',
  full_name='catalog.Author',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='catalog.Author.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='catalog.Author.first_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='catalog.Author.last_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_of_birth', full_name='catalog.Author.date_of_birth', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_of_death', full_name='catalog.Author.date_of_death', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=167,
)


_AUTHORLISTREQUEST = _descriptor.Descriptor(
  name='AuthorListRequest',
  full_name='catalog.AuthorListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=188,
)


_AUTHORRETRIEVEREQUEST = _descriptor.Descriptor(
  name='AuthorRetrieveRequest',
  full_name='catalog.AuthorRetrieveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='catalog.AuthorRetrieveRequest.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=225,
)

DESCRIPTOR.message_types_by_name['Author'] = _AUTHOR
DESCRIPTOR.message_types_by_name['AuthorListRequest'] = _AUTHORLISTREQUEST
DESCRIPTOR.message_types_by_name['AuthorRetrieveRequest'] = _AUTHORRETRIEVEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Author = _reflection.GeneratedProtocolMessageType('Author', (_message.Message,), {
  'DESCRIPTOR' : _AUTHOR,
  '__module__' : 'catalog.author_pb2'
  # @@protoc_insertion_point(class_scope:catalog.Author)
  })
_sym_db.RegisterMessage(Author)

AuthorListRequest = _reflection.GeneratedProtocolMessageType('AuthorListRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORLISTREQUEST,
  '__module__' : 'catalog.author_pb2'
  # @@protoc_insertion_point(class_scope:catalog.AuthorListRequest)
  })
_sym_db.RegisterMessage(AuthorListRequest)

AuthorRetrieveRequest = _reflection.GeneratedProtocolMessageType('AuthorRetrieveRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORRETRIEVEREQUEST,
  '__module__' : 'catalog.author_pb2'
  # @@protoc_insertion_point(class_scope:catalog.AuthorRetrieveRequest)
  })
_sym_db.RegisterMessage(AuthorRetrieveRequest)



_AUTHORCONTROLLER = _descriptor.ServiceDescriptor(
  name='AuthorController',
  full_name='catalog.AuthorController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=228,
  serialized_end=512,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='catalog.AuthorController.List',
    index=0,
    containing_service=None,
    input_type=_AUTHORLISTREQUEST,
    output_type=_AUTHOR,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='catalog.AuthorController.Create',
    index=1,
    containing_service=None,
    input_type=_AUTHOR,
    output_type=_AUTHOR,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Retrieve',
    full_name='catalog.AuthorController.Retrieve',
    index=2,
    containing_service=None,
    input_type=_AUTHORRETRIEVEREQUEST,
    output_type=_AUTHOR,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='catalog.AuthorController.Update',
    index=3,
    containing_service=None,
    input_type=_AUTHOR,
    output_type=_AUTHOR,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Destroy',
    full_name='catalog.AuthorController.Destroy',
    index=4,
    containing_service=None,
    input_type=_AUTHOR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHORCONTROLLER)

DESCRIPTOR.services_by_name['AuthorController'] = _AUTHORCONTROLLER

# @@protoc_insertion_point(module_scope)



import os
import pathlib

from setuptools import setup, find_packages

# The directory containing this file
HERE = pathlib.Path(__file__).parent
ROOT_DIR = os.path.dirname(os.path.abspath(__file__))

# This call to setup() does all the work
setup(
    name="qservices_library",
    version="1.2",
    description="Qustodio backend_workshop_microservices common repo",
    url="https://github.com/qustodio/backend_workshop_microservices",
    license="MIT",
    author="Qustodio developers",
    author_email="info@qustodio.com",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
    ],
    python_requires='>=3.6',
    packages=find_packages(include=['common', 'common.*']),
    include_package_data=False,
    install_requires=[
        "grpcio-tools==1.30"
    ],
    setup_requires=['flake8']
)
